==> 0.0.1%2B1.tar.gz: lib/models/IR5Article.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;

part 'IR5Article.g.dart';
// --------------------------------------------------------------------------------

/** After Pointage Auto Goto ... */
enum GotoMode { GotoPreparation, GotoDepartement, GotoOnglet }
const Map<int, GotoMode> GotoModes = {
  -10: GotoMode.GotoPreparation,
  -20: GotoMode.GotoDepartement,
  1: GotoMode.GotoOnglet,
};
int GotoModeToJson(GotoMode f) {
  return GotoModes.entries.firstWhere((element) => element.value == f).key;
}
// --------------------------------------------------------------------------------

/** Carton Composition or Stock Ingredients de l'article */
@JsonSerializable()
class IDetailStock {
  IDetailStock({
    required this.PLU,
    required this.Nom,
    required this.Qty,
  });

  factory IDetailStock.fromJson(Map<String, dynamic>? json) => _$IDetailStockFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IDetailStockToJson(this);

  @JsonKey(defaultValue: '')
  final String PLU;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num Qty;
}
// --------------------------------------------------------------------------------

/** Details Prepa/Departement de l'article */
@JsonSerializable()
class IDetailPrepa {
  IDetailPrepa({
    required this.PLU,
    required this.Nom,
    required this.Niveau,
  });

  factory IDetailPrepa.fromJson(Map<String, dynamic>? json) => _$IDetailPrepaFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IDetailPrepaToJson(this);

  @JsonKey(defaultValue: '')
  final String PLU;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num Niveau;
}
// --------------------------------------------------------------------------------

/** Menu Composition de l'article */
@JsonSerializable()
class IDetailMenu {
  IDetailMenu({
    required this.PLU,
    required this.Nom,
    required this.Niveau,
    required this.PxIn,
    required this.PxOut,
  });

  factory IDetailMenu.fromJson(Map<String, dynamic>? json) => _$IDetailMenuFromJson(json ?? {});

  Map<String, dynamic> toJson() => _$IDetailMenuToJson(this);

  @JsonKey(defaultValue: '')
  final String PLU;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num Niveau;
  @JsonKey(defaultValue: 0)
  final num PxIn;
  @JsonKey(defaultValue: 0)
  final num PxOut;
}
// --------------------------------------------------------------------------------

/** Articles */
@JsonSerializable(explicitToJson: true)
class IR5Article {
  IR5Article({
    required this.PLU,
    required this.Categorie,
    required this.Nom,
    required this.Type,
    required this.Flags,
    required this.Allergens,
    required this.Calories,
    required this.Action,
    required this.NomAddLg1,
    required this.NomAddLg2,
    required this.NomAddLg3,
    required this.NomProd,
    required this.BtnText,
    required this.BtnProp,
    required this.MemoCuisine,
    required this.Description,
    required this.ImageInfo,
    required this.ExtRef,
    required this.Tags,
    required this.WebOrder,
    required this.NomWebLg1,
    required this.NomWebLg2,
    required this.NomWebLg3,
    required this.WebDescrLg1,
    required this.WebDescrLg2,
    required this.WebDescrLg3,
    required this.Barcode,
    required this.Desti,
    required this.gotoMode,
    required this.GotoOnglet,
    required this.CategPos,
    required this.Groupe,
    required this.Divisions,
    required this.TVA,
    required this.TVACoeff,
    required this.TVAEmport,
    required this.TVAEmportCoeff,
    required this.PrixAchat,
    required this.PrixAchatEmport,
    required this.Prix1,
    required this.Prix2,
    required this.Prix3,
    required this.Prix4,
    required this.Prix1HappyHour,
    required this.Prix2HappyHour,
    required this.Prix3HappyHour,
    required this.Prix4HappyHour,
    required this.Unit,
    required this.Packaging,
    required this.Tare,
    required this.PrimeGarcon,
    required this.DetailsAuto,
    required this.DetailsPrepa,
    required this.DetailsMenu,
    required this.DetailsStock,
    required this.CreationDate,
    required this.LastModifDate,
    required this.LastModifStaff,
  });

  factory IR5Article.fromJson(Map<String, dynamic>? json) => _$IR5ArticleFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5ArticleToJson(this);

  /** Article Unique Code (Price Look-Up) */
  @JsonKey(defaultValue: '')
  final String PLU;

  /** Category to which the article belongs */
  @JsonKey(defaultValue: '')
  final String Categorie;

  /** Article Name (NomPLU/NomProd/NomAdd/...) */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Article Types
   *
   * 0 - Article Simple
   * 6 - Message Simple
   * 7 - Message Linked
   * 4 - Message Plus
   * 5 - Message Minus
   * 17 - Multiplicateur Quantite
   * 18 - Multiplicateur Discount
   * 19 - Multiplicateur Prix
   * 20 - Message Drapeau
   * 21 - Time Drapeau
   * 22 - TelNr Drapeau
   * 40 - Tête de Menu
   * 93 - Suite
   * 94 - Remise Sur Tot
   * 95 - Remise Sur Food
   * 96 - Remise Sur NonFood
   * 97 - Remise Sur Sel
   * 98 - Remise Abs
   * 99 - InternalAction
   */
  @JsonKey(defaultValue: 0)
  final num Type;

  /** Article Flags
   *   Bit 00 : Bloque
   *   Bit 01 : Pointe
   *   Bit 02 : Disabled
   *   Bit 03 : PrixASaissir
   *   Bit 04 : NomASaissir
   *   Bit 05 : OnlyResto
   *   Bit 06 : OnlyEmport
   *   Bit 07 : ForceEmport
   *   Bit 08 : PointageNoCumul
   *   Bit 09 : ForceResto
   *   Bit 10 : InterditAZero
   *   Bit 11 : InterditHorsMenu
   *   Bit 12 : InterditDansMenu
   *   Bit 13 : OnlyOnceRemise
   *   Bit 14 : Alcool
   *   Bit 15 : HappyHourQty
   *   Bit 16 : NotInTotalDiscount
   *   Bit 17 : NoChgPrix
   *   Bit 18 : NonFood
   *   Bit 19 : ControlINOUT
   *   Bit 20 : MenuForfaitCandidat
   *   Bit 21 : KeepStock
   *   Bit 22 : ListeReassort
   *   Bit 23 : BlocageAuto
   *   Bit 24 : AuCentimetre
   *   Bit 25 : NoDetailsIfResto
   *   Bit 26 : NoDetailsIfEmport
   *   Bit 27 : OnlyManager
   *   Bit 28 : Balance
   *   Bit 29 : External
   *   Bit 30 : AdditionNoCumul
   *   Bit 31 : NoTicketIfEmport
   *   Bit 32 : Deluxe
   *   Bit 33 : IsStockIngredient
   *   Bit 34 : IsStockCarton
   *   Bit 35 : StayInDepartement
   *   Bit 36 : ForceDetailLinked
   *   Bit 40 : PreparationOpen
   *   Bit 41 : PreparationControled
   *   Bit 42 : PreparationGrouped
   *   Bit 43 : PreparationShowNivDescr
   *   Bit 44 : PreparationSortByNom
   *   Bit 45 : NeedDrapeau4Lancer
   *   Bit 46 : NeedDrapeau4Add
   *   Bit 51 : RptModifFlag1
   *   Bit 52 : RptModifFlag2
   *   Bit 53 : RptModifFlag3
   *   Bit 54 : RptModifFlag4
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Allergens
   *   Bit 00 : Céréales
   *   Bit 01 : Crustacés
   *   Bit 02 : OEufs
   *   Bit 03 : Poissons
   *   Bit 04 : Arachides
   *   Bit 05 : Soja
   *   Bit 06 : Lait
   *   Bit 07 : Fruits à coque
   *   Bit 08 : Céleri
   *   Bit 09 : Moutarde
   *   Bit 10 : Graines de sésame
   *   Bit 11 : Anhydride sulfureux et sulfites
   *   Bit 12 : Lupin
   *   Bit 13 : Mollusques
   */
  @JsonKey(defaultValue: 0)
  final num Allergens;

  /** Cal. pour 100 g */
  @JsonKey(defaultValue: 0)
  final num Calories;
  /*
  @JsonKey(defaultValue: HistoAction.Article)
  final HistoAction? Action;
  */
  @JsonKey(defaultValue: '')
  final String Action;
  /** Article Name for Bills & Invoices. Coalesce to NomPLU */
  @JsonKey(defaultValue: '')
  final String NomAddLg1;

  /** Article Name for Bills & Invoices. Coalesce to NomPLU */
  @JsonKey(defaultValue: '')
  final String NomAddLg2;

  /** Article Name for Bills & Invoices. Coalesce to NomPLU */
  @JsonKey(defaultValue: '')
  final String NomAddLg3;

  /** Article Name for Tickets Productions (Kitchen/Bar/...). Coalesce to NomPLU. For all Languages, not only FR */
  @JsonKey(defaultValue: '')
  final String NomProd;

  /** Article Name for Screen Buttons. Coalesce to NomPLU. For all Languages, not only FR */
  @JsonKey(defaultValue: '')
  final String BtnText;

  final IR5BtnProperties? BtnProp;

  /** Article MEMOCUISINE */
  @JsonKey(defaultValue: '')
  final String MemoCuisine;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Big Image Info */
  @JsonKey(defaultValue: 0)
  final num ImageInfo;

  /** External Ref (used as primary key) */
  @JsonKey(defaultValue: '')
  final String ExtRef;

  /** Free Tags or Labels semicolumn separated */
  @JsonKey(defaultValue: '')
  final String Tags;

  /** Export to WebOrder Platforms (semicolumn separated list of Platforms)
   * Export ModePay if ModePay.WebOrder
   * Export Article if Article.WebOrder or Article.Categ.WebOrder or Article.Group.WebOrder
   */
  @JsonKey(defaultValue: '')
  final String WebOrder;

  /** Article WebName in Lg1. Coalesce to NomAdd[Lg1]. In Import will also Set NomAdd[Lg] if NomAdd[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg1;

  /** Article WebName in Lg2. Coalesce to NomAdd[Lg2]. In Import will also Set NomAdd[Lg] if NomAdd[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg2;

  /** Article WebName in Lg3. Coalesce to NomAdd[Lg3]. In Import will also Set NomAdd[Lg] if NomAdd[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg3;

  /** Article Web Memo Description in Lg1. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg1;

  /** Article Web Memo Description in Lg2. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg2;

  /** Article Web Memo Description in Lg3. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg3;

  /** Article Barcode */
  @JsonKey(defaultValue: '')
  final String Barcode;

  /** Printer Destination to which the article belongs */
  @JsonKey(defaultValue: 0)
  final num Desti;

  // --------------------------------------------------------------------------------

  /** After Pointage Auto Goto ... */
  /*
  @JsonKey(name: 'GotoMode', defaultValue: GotoMode.GotoOnglet)
  final GotoMode gotoMode;
  */
  @JsonKey(name: 'GotoMode', defaultValue: 0)
  final int gotoMode;

  /** Tab to which the article belongs */
  @JsonKey(defaultValue: 0)
  final num GotoOnglet;

  /** Article sort order in relation to the Category */
  @JsonKey(defaultValue: 0)
  final num CategPos;

  /** Group to which the article belongs */
  @JsonKey(defaultValue: 0)
  final num Groupe;

  /** Accessible Division(s) for the Station,Staff,Article,.. */
  @JsonKey(defaultValue: '')
  final String Divisions;

  /** VAT Rate level as Defined in Etab */
  @JsonKey(defaultValue: 0)
  final num TVA;

  /** Articles VAT Ratio
   * Ratio0;Ratio1;Ratio2;Ratio3
   * 0;0;35;65 -->  35% Ratio2 + 65% Ratio3
   * 0;100     --> 100% Ratio1
   * ;;;100    --> 100% Ratio3 same as TYPETVA=3
   */
  @JsonKey(defaultValue: '')
  final String TVACoeff;

  /** VAT Rate level as Defined in Etab */
  @JsonKey(defaultValue: 0)
  final num TVAEmport;

  /** Articles VAT Ratio
   * Ratio0;Ratio1;Ratio2;Ratio3
   * 0;0;35;65 -->  35% Ratio2 + 65% Ratio3
   * 0;100     --> 100% Ratio1
   * ;;;100    --> 100% Ratio3 same as TYPETVA=3
   */
  @JsonKey(defaultValue: '')
  final String TVAEmportCoeff;

  /** Article Purchasing/Cost Price w/o TAX */
  @JsonKey(defaultValue: 0)
  final num PrixAchat;

  /** Article Purchasing/Cost Price w/o TAX when RestoOut(Emport) */
  @JsonKey(defaultValue: 0)
  final num PrixAchatEmport;

  /** Article Selling Price 1 */
  @JsonKey(defaultValue: 0)
  final num Prix1;

  /** Article Selling Price 2 */
  @JsonKey(defaultValue: 0)
  final num Prix2;

  /** Article Selling Price 3 */
  @JsonKey(defaultValue: 0)
  final num Prix3;

  /** Article Selling Price 4 */
  @JsonKey(defaultValue: 0)
  final num Prix4;

  /** Article HappyHour Selling Price 1 OR Qt */
  @JsonKey(defaultValue: 0)
  final num Prix1HappyHour;

  /** Article HappyHour Selling Price 2 OR Qt */
  @JsonKey(defaultValue: 0)
  final num Prix2HappyHour;

  /** Article HappyHour Selling Price 3 OR Qt */
  @JsonKey(defaultValue: 0)
  final num Prix3HappyHour;

  /** Article HappyHour Selling Price 4 OR Qt */
  @JsonKey(defaultValue: 0)
  final num Prix4HappyHour;

  /** Article unit of measure (Kg,Ml,L,...) */
  @JsonKey(defaultValue: '')
  final String Unit;

  /** Units Article amount in a package */
  @JsonKey(defaultValue: 0)
  final num Packaging;

  /** Tare to remove when the Article is weighed */
  @JsonKey(defaultValue: 0)
  final num Tare;

  @JsonKey(defaultValue: 0)
  final num PrimeGarcon;

  /** Pointage auto */
  @JsonKey(defaultValue: [])
  final List<String> DetailsAuto;

  /** Details Prepa/Departement de l'article */
  @JsonKey(defaultValue: [])
  final List<IDetailPrepa> DetailsPrepa;

  /** Menu Composition de l'article */
  @JsonKey(defaultValue: [])
  final List<IDetailMenu> DetailsMenu;

  /** Carton Composition or Stock Ingredients de l'article */
  @JsonKey(defaultValue: [])
  final List<IDetailStock> DetailsStock;

  /** Date Creation */
  @JsonKey(defaultValue: '')
  final String CreationDate;

  /** Date Last Modif */
  @JsonKey(defaultValue: '')
  final String LastModifDate;

  /** Staff who did last modif */
  @JsonKey(defaultValue: 0)
  final num LastModifStaff;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5Article.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;

part 'IR5Article.g.dart';
// --------------------------------------------------------------------------------

/** After Pointage Auto Goto ... */
enum GotoMode { GotoPreparation, GotoDepartement, GotoOnglet }
const Map<int, GotoMode> GotoModes = {
  -10: GotoMode.GotoPreparation,
  -20: GotoMode.GotoDepartement,
  1: GotoMode.GotoOnglet,
};
int GotoModeToJson(GotoMode f) {
  return GotoModes.entries.firstWhere((element) => element.value == f).key;
}
// --------------------------------------------------------------------------------

/** Carton Composition or Stock Ingredients de l'article */
@JsonSerializable()
class IDetailStock {
  IDetailStock({
    required this.PLU,
    required this.Nom,
    required this.Qty,
  });

  factory IDetailStock.fromJson(Map<String, dynamic>? json) =>
      _$IDetailStockFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IDetailStockToJson(this);

  @JsonKey(defaultValue: '')
  final String PLU;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num Qty;
}
// --------------------------------------------------------------------------------

/** Details Prepa/Departement de l'article */
@JsonSerializable()
class IDetailPrepa {
  IDetailPrepa({
    required this.PLU,
    required this.Nom,
    required this.Niveau,
  });

  factory IDetailPrepa.fromJson(Map<String, dynamic>? json) =>
      _$IDetailPrepaFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IDetailPrepaToJson(this);

  @JsonKey(defaultValue: '')
  final String PLU;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num Niveau;
}
// --------------------------------------------------------------------------------

/** Menu Composition de l'article */
@JsonSerializable()
class IDetailMenu {
  IDetailMenu({
    required this.PLU,
    required this.Nom,
    required this.Niveau,
    required this.PxIn,
    required this.PxOut,
  });

  factory IDetailMenu.fromJson(Map<String, dynamic>? json) =>
      _$IDetailMenuFromJson(json ?? {});

  Map<String, dynamic> toJson() => _$IDetailMenuToJson(this);

  @JsonKey(defaultValue: '')
  final String PLU;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num Niveau;
  @JsonKey(defaultValue: 0)
  final num PxIn;
  @JsonKey(defaultValue: 0)
  final num PxOut;
}
// --------------------------------------------------------------------------------

/** Articles */
@JsonSerializable(explicitToJson: true)
class IR5Article {
  IR5Article({
    required this.PLU,
    required this.Categorie,
    required this.Nom,
    required this.Type,
    required this.Flags,
    required this.Allergens,
    required this.Calories,
    required this.Action,
    required this.NomAddLg1,
    required this.NomAddLg2,
    required this.NomAddLg3,
    required this.NomProd,
    required this.BtnText,
    required this.BtnProp,
    required this.MemoCuisine,
    required this.Description,
    required this.ImageInfo,
    required this.ExtRef,
    required this.Tags,
    required this.WebOrder,
    required this.NomWebLg1,
    required this.NomWebLg2,
    required this.NomWebLg3,
    required this.WebDescrLg1,
    required this.WebDescrLg2,
    required this.WebDescrLg3,
    required this.Barcode,
    required this.Desti,
    required this.gotoMode,
    required this.GotoOnglet,
    required this.CategPos,
    required this.Groupe,
    required this.Divisions,
    required this.TVA,
    required this.TVACoeff,
    required this.TVAEmport,
    required this.TVAEmportCoeff,
    required this.PrixAchat,
    required this.PrixAchatEmport,
    required this.Prix1,
    required this.Prix2,
    required this.Prix3,
    required this.Prix4,
    required this.Prix1HappyHour,
    required this.Prix2HappyHour,
    required this.Prix3HappyHour,
    required this.Prix4HappyHour,
    required this.Unit,
    required this.Packaging,
    required this.Tare,
    required this.PrimeGarcon,
    required this.DetailsAuto,
    required this.DetailsPrepa,
    required this.DetailsMenu,
    required this.DetailsStock,
    required this.CreationDate,
    required this.LastModifDate,
    required this.LastModifStaff,
  });

  factory IR5Article.fromJson(Map<String, dynamic>? json) =>
      _$IR5ArticleFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5ArticleToJson(this);

  /** Article Unique Code (Price Look-Up) */
  @JsonKey(defaultValue: '')
  final String PLU;

  /** Category to which the article belongs */
  @JsonKey(defaultValue: '')
  final String Categorie;

  /** Article Name (NomPLU/NomProd/NomAdd/...) */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Article Types
   *
   * 0 - Article Simple
   * 6 - Message Simple
   * 7 - Message Linked
   * 4 - Message Plus
   * 5 - Message Minus
   * 17 - Multiplicateur Quantite
   * 18 - Multiplicateur Discount
   * 19 - Multiplicateur Prix
   * 20 - Message Drapeau
   * 21 - Time Drapeau
   * 22 - TelNr Drapeau
   * 40 - Tête de Menu
   * 93 - Suite
   * 94 - Remise Sur Tot
   * 95 - Remise Sur Food
   * 96 - Remise Sur NonFood
   * 97 - Remise Sur Sel
   * 98 - Remise Abs
   * 99 - InternalAction
   */
  @JsonKey(defaultValue: 0)
  final num Type;

  /** Article Flags
   *   Bit 00 : Bloque
   *   Bit 01 : Pointe
   *   Bit 02 : Disabled
   *   Bit 03 : PrixASaissir
   *   Bit 04 : NomASaissir
   *   Bit 05 : OnlyResto
   *   Bit 06 : OnlyEmport
   *   Bit 07 : ForceEmport
   *   Bit 08 : PointageNoCumul
   *   Bit 09 : ForceResto
   *   Bit 10 : InterditAZero
   *   Bit 11 : InterditHorsMenu
   *   Bit 12 : InterditDansMenu
   *   Bit 13 : OnlyOnceRemise
   *   Bit 14 : Alcool
   *   Bit 15 : HappyHourQty
   *   Bit 16 : NotInTotalDiscount
   *   Bit 17 : NoChgPrix
   *   Bit 18 : NonFood
   *   Bit 19 : ControlINOUT
   *   Bit 20 : MenuForfaitCandidat
   *   Bit 21 : KeepStock
   *   Bit 22 : ListeReassort
   *   Bit 23 : BlocageAuto
   *   Bit 24 : AuCentimetre
   *   Bit 25 : NoDetailsIfResto
   *   Bit 26 : NoDetailsIfEmport
   *   Bit 27 : OnlyManager
   *   Bit 28 : Balance
   *   Bit 29 : External
   *   Bit 30 : AdditionNoCumul
   *   Bit 31 : NoTicketIfEmport
   *   Bit 32 : Deluxe
   *   Bit 33 : IsStockIngredient
   *   Bit 34 : IsStockCarton
   *   Bit 35 : StayInDepartement
   *   Bit 36 : ForceDetailLinked
   *   Bit 40 : PreparationOpen
   *   Bit 41 : PreparationControled
   *   Bit 42 : PreparationGrouped
   *   Bit 43 : PreparationShowNivDescr
   *   Bit 44 : PreparationSortByNom
   *   Bit 45 : NeedDrapeau4Lancer
   *   Bit 46 : NeedDrapeau4Add
   *   Bit 51 : RptModifFlag1
   *   Bit 52 : RptModifFlag2
   *   Bit 53 : RptModifFlag3
   *   Bit 54 : RptModifFlag4
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Allergens
   *   Bit 00 : Céréales
   *   Bit 01 : Crustacés
   *   Bit 02 : OEufs
   *   Bit 03 : Poissons
   *   Bit 04 : Arachides
   *   Bit 05 : Soja
   *   Bit 06 : Lait
   *   Bit 07 : Fruits à coque
   *   Bit 08 : Céleri
   *   Bit 09 : Moutarde
   *   Bit 10 : Graines de sésame
   *   Bit 11 : Anhydride sulfureux et sulfites
   *   Bit 12 : Lupin
   *   Bit 13 : Mollusques
   */
  @JsonKey(defaultValue: 0)
  final num Allergens;

  /** Cal. pour 100 g */
  @JsonKey(defaultValue: 0)
  final num Calories;
  /*
  @JsonKey(defaultValue: HistoAction.Article)
  final HistoAction? Action;
  */
  @JsonKey(defaultValue: '')
  final String Action;
  /** Article Name for Bills & Invoices. Coalesce to NomPLU */
  @JsonKey(defaultValue: '')
  final String NomAddLg1;

  /** Article Name for Bills & Invoices. Coalesce to NomPLU */
  @JsonKey(defaultValue: '')
  final String NomAddLg2;

  /** Article Name for Bills & Invoices. Coalesce to NomPLU */
  @JsonKey(defaultValue: '')
  final String NomAddLg3;

  /** Article Name for Tickets Productions (Kitchen/Bar/...). Coalesce to NomPLU. For all Languages, not only FR */
  @JsonKey(defaultValue: '')
  final String NomProd;

  /** Article Name for Screen Buttons. Coalesce to NomPLU. For all Languages, not only FR */
  @JsonKey(defaultValue: '')
  final String BtnText;

  final IR5BtnProperties? BtnProp;

  /** Article MEMOCUISINE */
  @JsonKey(defaultValue: '')
  final String MemoCuisine;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Big Image Info */
  @JsonKey(defaultValue: 0)
  final num ImageInfo;

  /** External Ref (used as primary key) */
  @JsonKey(defaultValue: '')
  final String ExtRef;

  /** Free Tags or Labels semicolumn separated */
  @JsonKey(defaultValue: '')
  final String Tags;

  /** Export to WebOrder Platforms (semicolumn separated list of Platforms)
   * Export ModePay if ModePay.WebOrder
   * Export Article if Article.WebOrder or Article.Categ.WebOrder or Article.Group.WebOrder
   */
  @JsonKey(defaultValue: '')
  final String WebOrder;

  /** Article WebName in Lg1. Coalesce to NomAdd[Lg1]. In Import will also Set NomAdd[Lg] if NomAdd[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg1;

  /** Article WebName in Lg2. Coalesce to NomAdd[Lg2]. In Import will also Set NomAdd[Lg] if NomAdd[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg2;

  /** Article WebName in Lg3. Coalesce to NomAdd[Lg3]. In Import will also Set NomAdd[Lg] if NomAdd[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg3;

  /** Article Web Memo Description in Lg1. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg1;

  /** Article Web Memo Description in Lg2. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg2;

  /** Article Web Memo Description in Lg3. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg3;

  /** Article Barcode */
  @JsonKey(defaultValue: '')
  final String Barcode;

  /** Printer Destination to which the article belongs */
  @JsonKey(defaultValue: 0)
  final num Desti;

  // --------------------------------------------------------------------------------

  /** After Pointage Auto Goto ... */
  /*
  @JsonKey(name: 'GotoMode', defaultValue: GotoMode.GotoOnglet)
  final GotoMode gotoMode;
  */
  @JsonKey(name: 'GotoMode', defaultValue: 0)
  final int gotoMode;

  /** Tab to which the article belongs */
  @JsonKey(defaultValue: 0)
  final num GotoOnglet;

  /** Article sort order in relation to the Category */
  @JsonKey(defaultValue: 0)
  final num CategPos;

  /** Group to which the article belongs */
  @JsonKey(defaultValue: 0)
  final num Groupe;

  /** Accessible Division(s) for the Station,Staff,Article,.. */
  @JsonKey(defaultValue: '')
  final String Divisions;

  /** VAT Rate level as Defined in Etab */
  @JsonKey(defaultValue: 0)
  final num TVA;

  /** Articles VAT Ratio
   * Ratio0;Ratio1;Ratio2;Ratio3
   * 0;0;35;65 -->  35% Ratio2 + 65% Ratio3
   * 0;100     --> 100% Ratio1
   * ;;;100    --> 100% Ratio3 same as TYPETVA=3
   */
  @JsonKey(defaultValue: '')
  final String TVACoeff;

  /** VAT Rate level as Defined in Etab */
  @JsonKey(defaultValue: 0)
  final num TVAEmport;

  /** Articles VAT Ratio
   * Ratio0;Ratio1;Ratio2;Ratio3
   * 0;0;35;65 -->  35% Ratio2 + 65% Ratio3
   * 0;100     --> 100% Ratio1
   * ;;;100    --> 100% Ratio3 same as TYPETVA=3
   */
  @JsonKey(defaultValue: '')
  final String TVAEmportCoeff;

  /** Article Purchasing/Cost Price w/o TAX */
  @JsonKey(defaultValue: 0)
  final num PrixAchat;

  /** Article Purchasing/Cost Price w/o TAX when RestoOut(Emport) */
  @JsonKey(defaultValue: 0)
  final num PrixAchatEmport;

  /** Article Selling Price 1 */
  @JsonKey(defaultValue: 0)
  final num Prix1;

  /** Article Selling Price 2 */
  @JsonKey(defaultValue: 0)
  final num Prix2;

  /** Article Selling Price 3 */
  @JsonKey(defaultValue: 0)
  final num Prix3;

  /** Article Selling Price 4 */
  @JsonKey(defaultValue: 0)
  final num Prix4;

  /** Article HappyHour Selling Price 1 OR Qt */
  @JsonKey(defaultValue: 0)
  final num Prix1HappyHour;

  /** Article HappyHour Selling Price 2 OR Qt */
  @JsonKey(defaultValue: 0)
  final num Prix2HappyHour;

  /** Article HappyHour Selling Price 3 OR Qt */
  @JsonKey(defaultValue: 0)
  final num Prix3HappyHour;

  /** Article HappyHour Selling Price 4 OR Qt */
  @JsonKey(defaultValue: 0)
  final num Prix4HappyHour;

  /** Article unit of measure (Kg,Ml,L,...) */
  @JsonKey(defaultValue: '')
  final String Unit;

  /** Units Article amount in a package */
  @JsonKey(defaultValue: 0)
  final num Packaging;

  /** Tare to remove when the Article is weighed */
  @JsonKey(defaultValue: 0)
  final num Tare;

  @JsonKey(defaultValue: 0)
  final num PrimeGarcon;

  /** Pointage auto */
  @JsonKey(defaultValue: [])
  final List<String> DetailsAuto;

  /** Details Prepa/Departement de l'article */
  @JsonKey(defaultValue: [])
  final List<IDetailPrepa> DetailsPrepa;

  /** Menu Composition de l'article */
  @JsonKey(defaultValue: [])
  final List<IDetailMenu> DetailsMenu;

  /** Carton Composition or Stock Ingredients de l'article */
  @JsonKey(defaultValue: [])
  final List<IDetailStock> DetailsStock;

  /** Date Creation */
  @JsonKey(defaultValue: '')
  final String CreationDate;

  /** Date Last Modif */
  @JsonKey(defaultValue: '')
  final String LastModifDate;

  /** Staff who did last modif */
  @JsonKey(defaultValue: 0)
  final num LastModifStaff;
}
